pub struct RegistryConfig {
pub storage: StorageConfig,
pub compatibility: CompatibilityLevel,
pub normalize_schemas: bool,
pub id_generation: IdGeneration,
pub max_cache_size: usize,
}Expand description
Configuration for the Schema Registry
Fields
storage: StorageConfigStorage backend configuration
compatibility: CompatibilityLevelDefault compatibility level
normalize_schemas: boolEnable schema normalization before storing
id_generation: IdGenerationSchema ID generation mode
max_cache_size: usizeMaximum number of schemas to cache in memory (0 = unlimited). When the limit is reached, the oldest entries are evicted.
Implementations
Sourceimpl RegistryConfig
impl RegistryConfig
Sourcepub fn broker(config: BrokerStorageConfig) -> Self
pub fn broker(config: BrokerStorageConfig) -> Self
Create config with broker-backed storage
Sourcepub fn with_compatibility(self, level: CompatibilityLevel) -> Self
pub fn with_compatibility(self, level: CompatibilityLevel) -> Self
Set compatibility level
Sourcepub fn with_normalize(self, normalize: bool) -> Self
pub fn with_normalize(self, normalize: bool) -> Self
Set schema normalization