CompatibilityLevel

Enum CompatibilityLevel 

pub enum CompatibilityLevel {
    Backward,
    BackwardTransitive,
    Forward,
    ForwardTransitive,
    Full,
    FullTransitive,
    None,
}
Compatibility level for schema evolution

LevelDescriptionCan Read
BACKWARDNew schema can read old dataOld → New ✓
FORWARDOld schema can read new dataNew → Old ✓
FULLBoth directionsBoth ✓
NONENo checking-

Variants



Backward

New schema can read data written by old schema (default) Safe for consumers to upgrade first



BackwardTransitive

New schema can read data written by old schema (transitive)



Forward

Old schema can read data written by new schema Safe for producers to upgrade first



ForwardTransitive

Old schema can read data written by new schema (transitive)



Full

Both backward and forward compatible



FullTransitive

Both backward and forward compatible (transitive)



None

No compatibility checking

Implementations

Source

impl CompatibilityLevel

pub fn is_backward(&self) -> bool

Check if this level requires backward compatibility

pub fn is_forward(&self) -> bool

Check if this level requires forward compatibility

pub fn is_transitive(&self) -> bool

Check if this level is transitive (checks all versions)